==> easypost-api-client-6.0.0-rc1-sources.jar: com/easypost/service/ScanformService.java <==
package com.easypost.service;

import com.easypost.exception.EasyPostException;
import com.easypost.http.Requestor;
import com.easypost.http.Requestor.RequestMethod;
import com.easypost.model.ScanForm;
import com.easypost.model.ScanFormCollection;
import com.easypost.utils.Utilities;

import java.util.Map;

public class ScanformService {
    private final EasyPostClient client;

    /**
     * ScanformService constructor.
     * 
     * @param client The client object.
     */
    ScanformService(EasyPostClient client) {
        this.client = client;
    }

    /**
     * Create a ScanForm from a map of parameters.
     *
     * @param params the map of parameters.
     * @return ScanForm object.
     * @throws EasyPostException when the request fails. when the request fails.
     */
    public ScanForm create(final Map<String, Object> params) throws EasyPostException {
        return Requestor.request(RequestMethod.POST, Utilities.classURL(ScanForm.class), params, ScanForm.class,
                client);
    }

    /**
     * Retrieve a ScanForm from the API.
     *
     * @param id the id of the ScanForm to retrieve.
     * @return ScanForm object.
     * @throws EasyPostException when the request fails. when the request fails.
     */
    public ScanForm retrieve(final String id) throws EasyPostException {
        return Requestor.request(RequestMethod.GET, Utilities.instanceURL(ScanForm.class, id), null, ScanForm.class,
                client);
    }

    /**
     * Get a list of ScanForms from the API.
     *
     * @param params the parameters to send to the API.
     * @return ScanFormCollection object.
     * @throws EasyPostException when the request fails. when the request fails.
     */
    public ScanFormCollection all(final Map<String, Object> params)
            throws EasyPostException {
        return Requestor.request(RequestMethod.GET, Utilities.classURL(ScanForm.class), params,
                ScanFormCollection.class, client);
    }
}

==> easypost-api-client-6.2.0-sources.jar: com/easypost/service/ScanformService.java <==
package com.easypost.service;

import com.easypost.exception.EasyPostException;
import com.easypost.http.Requestor;
import com.easypost.http.Requestor.RequestMethod;
import com.easypost.model.ScanForm;
import com.easypost.model.ScanFormCollection;
import com.easypost.utils.InternalUtilities;

import java.util.Map;

public class ScanformService {
    private final EasyPostClient client;

    /**
     * ScanformService constructor.
     * 
     * @param client The client object.
     */
    ScanformService(EasyPostClient client) {
        this.client = client;
    }

    /**
     * Create a ScanForm from a map of parameters.
     *
     * @param params the map of parameters.
     * @return ScanForm object.
     * @throws EasyPostException when the request fails. when the request fails.
     */
    public ScanForm create(final Map<String, Object> params) throws EasyPostException {
        return Requestor.request(RequestMethod.POST, InternalUtilities.classURL(ScanForm.class), params, ScanForm.class,
                client);
    }

    /**
     * Retrieve a ScanForm from the API.
     *
     * @param id the id of the ScanForm to retrieve.
     * @return ScanForm object.
     * @throws EasyPostException when the request fails. when the request fails.
     */
    public ScanForm retrieve(final String id) throws EasyPostException {
        return Requestor.request(RequestMethod.GET, InternalUtilities.instanceURL(ScanForm.class, id), null,
                ScanForm.class, client);
    }

    /**
     * Get a list of ScanForms from the API.
     *
     * @param params the parameters to send to the API.
     * @return ScanFormCollection object.
     * @throws EasyPostException when the request fails. when the request fails.
     */
    public ScanFormCollection all(final Map<String, Object> params)
            throws EasyPostException {
        return Requestor.request(RequestMethod.GET, InternalUtilities.classURL(ScanForm.class), params,
                ScanFormCollection.class, client);
    }
}
